[![CI Status]][workflow]

[CI Status]: https://img.shields.io/github/actions/workflow/status/juntyr/numcodecs-rs/ci.yml?branch=main
[workflow]: https://github.com/juntyr/numcodecs-rs/actions/workflows/ci.yml?query=branch%3Amain

# numcodecs-wasm-uniform-noise

[`numcodecs`] compression for the [`numcodecs-uniform-noise`] codec compiled to WebAssembly.

[`numcodecs`]: https://numcodecs.readthedocs.io/en/stable/
[`numcodecs-uniform-noise`]: https://docs.rs/numcodecs-uniform-noise/

## License

Licensed under the Mozilla Public License, Version 2.0 ([LICENSE](LICENSE) or https://www.mozilla.org/en-US/MPL/2.0/).

## Funding

The `numcodecs-wasm-uniform-noise` package has been developed as part of [ESiWACE3](https://www.esiwace.eu), the third phase of the Centre of Excellence in Simulation of Weather and Climate in Europe.

Funded by the European Union. This work has received funding from the European High Performance Computing Joint Undertaking (JU) under grant agreement No 101093054.
